@@ -22,8 +22,8 @@
 #include <iconv.h>
 
 
-char*
-chxj_encoding(request_rec *r, const char* src, apr_size_t* len)
+char *
+chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
 {
   char*               obuf;
   char*               ibuf;
@@ -39,7 +39,7 @@ chxj_encoding(request_rec *r, const char* src, apr_size_t* len)
 
   DBG(r,"start chxj_encoding()");
 
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
   if (dconf == NULL) {
     DBG(r,"none encoding.");
@@ -100,7 +100,7 @@ chxj_encoding(request_rec *r, const char* src, apr_size_t* len)
       break;
     }
   }
-  *len = olen;
+  *len = strlen(spos);
   iconv_close(cd);
 
   DBG(r,"end   chxj_encoding() len=[%d] obuf=[%.*s]", (int)*len, (int)*len, spos);
@@ -124,7 +124,7 @@ chxj_rencoding(request_rec *r, const char* src, apr_size_t* len)
 
   DBG(r,"start chxj_rencoding()");
 
-  dconf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
   if (! dconf) {
     DBG(r,"none encoding.");
     DBG(r,"end   chxj_rencoding()");
@@ -189,7 +189,7 @@ chxj_rencoding(request_rec *r, const char* src, apr_size_t* len)
     }
   }
 
-  *len = olen;
+  *len = strlen(spos);
   iconv_close(cd);
 
   DBG(r,"end   chxj_rencoding() len=[%d] obuf=[%.*s]", (int)*len, (int)*len, spos);
