@@ -601,7 +601,7 @@ chxj_qr_code_handler(request_rec* r)
   /*--------------------------------------------------------------------------*/
   /* ⤷᡼ѴϥɥǤСǤϽʤ                 */
   /*--------------------------------------------------------------------------*/
-  conf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  conf = chxj_get_module_config(r->per_dir_config, &chxj_module);
   if (!conf || conf->image == CHXJ_IMG_ON)
     return DECLINED;
 
@@ -627,7 +627,7 @@ chxj_qr_code_handler(request_rec* r)
   if (sts != OK)
     return sts;
 
-  ap_set_content_type(r, "image/jpg");
+  chxj_set_content_type(r, "image/jpg");
 
   ap_rwrite((void*)img, len, r);
 
@@ -669,7 +669,7 @@ chxj_qr_code_blob_handler(request_rec* r, const char* indata, size_t* len)
     return NULL;
   }
 
-  ap_set_content_type(r, "image/jpg");
+  chxj_set_content_type(r, "image/jpg");
 
   DBG(r, "end chxj_qr_code_blob_handler()");
 
